@@ -5,12 +5,12 @@ from datetime import datetime, timedelta
 from email.mime.multipart import MIMEMultipart
 from email.mime.base import MIMEBase
 from email.mime.text import MIMEText
-# from jinja2 import Template
+from jinja2 import Template
 from multiprocessing import Pool
 
 from .. import core
 from ..consts import CONFIG
-# from ..consts import RAPPORT_HTML
+from ..consts import RAPPORT_HTML
 from ..consts import REDIS_DB
 from ..customer import Customer
 from ..product import Product
@@ -68,12 +68,12 @@ def notify():
 @cmd.command()
 @click.option('--for-real', is_flag=True, default=False)
 @click.option('--send-mail', is_flag=True, default=False)
-def apply(for_real, send_mail):
+@click.option('--random', is_flag=True, default=False)
+def apply(for_real, send_mail, random):
     """Appliquer les politiques de FUP pour tous les clients Business"""
 
-    def str_data(conso_bytes):
-        result = round(conso_bytes/1000000000, 2)
-        result = str(result).replace('.', ',')
+    def str_data(conso_gigabytes):
+        result = str(conso_gigabytes).replace('.', ',')
         if result == '0,0':
             return '0'
         else:
@@ -81,8 +81,9 @@ def apply(for_real, send_mail):
 
     result = {}
     products = Product.all()
+    products = sorted(products, key=lambda x: x.name, reverse=True)
     for product in products:
-        policies = product.apply_policies(for_real=for_real)
+        policies = product.apply_policies(for_real=for_real, random=random)
         if policies:
             result[product.name] = policies
     if result:
@@ -108,14 +109,10 @@ def apply(for_real, send_mail):
             'data_limit',
             'policy_name',
             'customer',
-            'download_international',
-            'download_cache',
+            'total_download',
+            'total_upload',
             'download_national',
-            'upload_international',
-            'upload_cache',
             'upload_national',
-            'total_download_for_fup',
-            'total_upload_for_fup',
             'total',
             'status'
             ]
@@ -123,6 +120,8 @@ def apply(for_real, send_mail):
         for product in products:
             policies = result[product]
             message += 'Produit: {product}\n'.format(product=product)
+            number_fup_in = 0
+            number_fup_out = 0
             for policy in policies:
                 message += (
                     '\n'
@@ -131,8 +130,6 @@ def apply(for_real, send_mail):
                         data_limit=policy['data_limit']
                         )
                 foo = ''
-                number_fup_in = 0
-                number_fup_out = 0
                 fup_true = 0
                 total_client = len(policy['customers'])
                 for customer, data in policy['customers'].items():
@@ -148,7 +145,6 @@ def apply(for_real, send_mail):
                             reverse=True
                             )
                         policy_status = customer_policy_status[0]['status']
-
                     conso = {
                         'internet': {'octets_in': 0, 'octets_out': 0},
                         'national': {'octets_in': 0, 'octets_out': 0},
@@ -159,9 +155,12 @@ def apply(for_real, send_mail):
                         octets_in = source['octets_in']
                         octets_out = source['octets_out']
                         conso[source_name] = source
-                        conso[source_name]['octets_in'] = str_data(octets_in)
-                        conso[source_name]['octets_out'] = str_data(octets_out)
-                    click.echo(conso)
+                        conso[source_name]['octets_in'] = str_data(
+                            round(octets_in/1000000000, 2)
+                            )
+                        conso[source_name]['octets_out'] = str_data(
+                            round(octets_out/1000000000, 2)
+                            )
                     total_octets_in = str_data(data['octets_in'])
                     total_octets_out = str_data(data['octets_out'])
                     total = str_data(data['total'])
@@ -171,14 +170,10 @@ def apply(for_real, send_mail):
                             str(policy['data_limit']).replace('.', ','),
                             policy['name'],
                             customer,
-                            conso['internet']['octets_in'],
-                            conso['cache']['octets_in'],
-                            conso['national']['octets_in'],
-                            conso['internet']['octets_out'],
-                            conso['cache']['octets_out'],
-                            conso['national']['octets_out'],
                             total_octets_in,
                             total_octets_out,
+                            conso['national']['octets_in'],
+                            conso['national']['octets_out'],
                             total,
                             policy_status
                             ]
@@ -209,6 +204,16 @@ def apply(for_real, send_mail):
                 pourcentage_fup = fup_true * 100 / total_client
                 pourcentage_fup = round(pourcentage_fup)
                 pourcentage_fup = '{}%'.format(pourcentage_fup)
+                dataset_synthesis.append(
+                    [
+                        policy['name'],
+                        product,
+                        fup_false,
+                        fup_true,
+                        total_client,
+                        pourcentage_fup
+                        ]
+                    )
             dataset_statistics.append(
                 [
                     product,
@@ -216,32 +221,23 @@ def apply(for_real, send_mail):
                     number_fup_out
                     ]
                 )
-            dataset_synthesis.append(
-                [
-                    policy['name'],
-                    product,
-                    fup_false,
-                    fup_true,
-                    total_client,
-                    pourcentage_fup
-                    ]
-                )
             message += '\n\n\n'
         message += str(dataset_statistics)
         message += '\n\n\n'
         message += str(dataset_synthesis)
-        # message_html = Template(RAPPORT_HTML).render(
-        #     date=datetime.now().date().strftime('%d/%m/%Y'),
-        #     products=products,
-        #     result=result
-        #     )
+        message_html = Template(RAPPORT_HTML).render(
+            date=datetime.now().date().strftime('%d/%m/%Y'),
+            result=result,
+            stats=dataset_statistics,
+            synthesis=dataset_synthesis
+            )
         click.echo(message)
         with open('/tmp/details.csv', 'w') as f:
             f.write(dataset.export('csv', delimiter=';'))
         if send_mail:
             recipients = CONFIG['ALERT']['to']
             content_text = MIMEText(message, 'plain', 'utf-8')
-            # content_html = MIMEText(message_html, 'html', 'utf-8')
+            content_html = MIMEText(message_html, 'html', 'utf-8')
             attachment = MIMEBase('text', 'csv')
             fp = open('/tmp/details.csv', 'rb')
             attachment.set_payload(fp.read())
@@ -252,15 +248,15 @@ def apply(for_real, send_mail):
                 filename='details.csv'
                 )
 
-            msg = MIMEMultipart()
+            msg = MIMEMultipart('related')
             msg['Subject'] = CONFIG['ALERT']['subject']
             msg['From'] = CONFIG['ALERT']['from']
             msg['To'] = recipients
-            # msg_body = MIMEMultipart('alternative')
+            msg_body = MIMEMultipart('alternative')
+            msg_body.attach(content_html)
+            msg_body.attach(content_text)
+            msg.attach(msg_body)
             msg.attach(attachment)
-            # msg.attach(msg_body)
-            # msg.attach(content_html)
-            msg.attach(content_text)
             s = smtplib.SMTP('localhost')
             s.sendmail(
                 CONFIG['ALERT']['from'],
