@@ -23,7 +23,7 @@ class Customer(object):
     """Un client internet est identifié par un nom, un refnum et un produit"""
 
     def __init__(self, name):
-        self.name = name
+        self.name = name.lower()
         url = core.database_url(**FUPDB_CREDENTIALS)
         with records.Database(url) as db:
             sql = "SELECT refnum, product FROM customer WHERE name=:name"
@@ -373,25 +373,24 @@ class Customer(object):
                 info['fup_in'] = True
             elif info['total'] < info['data_limit'] and status:
                 info['fup_out'] = True
-
-            if info.get('fup_in'):  # à limiter
-                url = core.database_url(**FUPDB_CREDENTIALS)
-                with records.Database(url) as db:
-                    sql = (
-                        "INSERT INTO fup "
-                        "(customer, product, policy, datetime, status) "
-                        "VALUES "
-                        "(:name, :product, :policy, :date_time, :status)"
-                        )
-                    db.query(
-                        sql,
-                        name=self.name,
-                        product=self.product.name,
-                        policy=info['name'],
-                        date_time=datetime.now(),
-                        status=True
-                        )
-                if for_real:  # demander à Aiguillier de le faire
+            if for_real:
+                if info.get('fup_in'):  # à limiter
+                    url = core.database_url(**FUPDB_CREDENTIALS)
+                    with records.Database(url) as db:
+                        sql = (
+                            "INSERT INTO fup "
+                            "(customer, product, policy, datetime, status) "
+                            "VALUES "
+                            "(:name, :product, :policy, :date_time, :status)"
+                            )
+                        db.query(
+                            sql,
+                            name=self.name,
+                            product=self.product.name,
+                            policy=info['name'],
+                            date_time=datetime.now(),
+                            status=True
+                            )
                     REST_CLIENT.post(
                         '/fup',
                         auth=(
@@ -400,24 +399,23 @@ class Customer(object):
                             ),
                         params={'customer': self.name}
                         )
-            elif info.get('fup_out'):  # libérer
-                url = core.database_url(**FUPDB_CREDENTIALS)
-                with records.Database(url) as db:
-                    sql = (
-                        "INSERT INTO fup "
-                        "(customer, product, policy, datetime, status) "
-                        "VALUES "
-                        "(:name, :product, :policy, :date_time, :status)"
-                        )
-                    db.query(
-                        sql,
-                        name=self.name,
-                        product=self.product.name,
-                        policy=info['name'],
-                        date_time=datetime.now(),
-                        status=False
-                        )
-                if for_real:  # demander à Aiguillier de le faire
+                elif info.get('fup_out'):  # libérer
+                    url = core.database_url(**FUPDB_CREDENTIALS)
+                    with records.Database(url) as db:
+                        sql = (
+                            "INSERT INTO fup "
+                            "(customer, product, policy, datetime, status) "
+                            "VALUES "
+                            "(:name, :product, :policy, :date_time, :status)"
+                            )
+                        db.query(
+                            sql,
+                            name=self.name,
+                            product=self.product.name,
+                            policy=info['name'],
+                            date_time=datetime.now(),
+                            status=False
+                            )
                     REST_CLIENT.delete(
                         '/fup',
                         auth=(
