@@ -4,6 +4,7 @@
 
 from functools import partial
 from multiprocessing.pool import Pool
+from random import sample
 
 from .consts import CONFIG
 from .consts import FUPDB_CREDENTIALS
@@ -57,13 +58,16 @@ class Product(object):
         products = set(['_'.join(i.split('_')[:-1]) for i in policy_names])
         return [Product(name) for name in products]
 
-    def apply_policies(self, for_real=False):
+    def apply_policies(self, for_real=False, random=False):
         """Application des politiques de bon usage à tous les clients
         abonnés à ce produit."""
 
+        customers = self.customers
+        if random:
+            customers = sample(customers, 3)
         f = partial(core.apply_product_policies, for_real)
         with Pool(4) as p:
-            response = p.map(f, self.customers)
+            response = p.map(f, customers)
         customers = {i[0].name: i[1] for i in response if i[1]}
         policies = []
         for policy_name, policy in self.policies.items():
@@ -118,7 +122,7 @@ class Product(object):
             pass
         else:
             customers = {
-                customer['name']: {
+                customer['name'].lower(): {
                     'product': customer['product'],
                     'refnum': customer['refnum']
                     }
@@ -141,6 +145,9 @@ class Product(object):
                             refnum=infos['refnum'],
                             product=infos['product']
                             )
+                    LOGS.logger.info(
+                        "Inscription du client {}".format(customer)
+                        )
                 else:
                     # on vérifie si son refnum a changé
                     if existing_customer['refnum'] != infos['refnum']:
